import PermissionChecker from '../../services/user/permissionChecker'
import ApiResponseHandler from '../apiResponseHandler'
import Permissions from '../../security/permissions'
import NoteService from '../../services/noteService'

// /**
//  * DELETE /tenant/{tenantId}/note/{id}
//  * @summary Delete a note
//  * @tag Notes
//  * @security Bearer
//  * @description Delete a note.
//  * @pathParam {string} tenantId - Your workspace/tenant ID
//  * @pathParam {string} id - The ID of the note
//  * @response 200 - Ok
//  * @response 401 - Unauthorized
//  * @response 404 - Not found
//  * @response 429 - Too many requests
// //  */
export default async (req, res) => {
  try {
    new PermissionChecker(req).validateHas(Permissions.values.noteDestroy)

    await new NoteService(req).destroyAll(req.query.ids)

    const payload = true

    await ApiResponseHandler.success(req, res, payload)
  } catch (error) {
    await ApiResponseHandler.error(req, res, error)
  }
}
